<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\LinkParsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use RuntimeException;
use SimpleXMLIterator;

/**
 * Class BaseLinkParser
 * @package Infomaker\Everyware\NewsML\LinkParsers
 */
abstract class BaseLinkParser implements ItemParser, TypeParser
{
    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill($this->getLinkData($item));

        return [$item];
    }

    protected function getLinkData(Item $item): array
    {
        return [];
    }

    public function typeToParse(): string
    {
        if ( ! defined(static::class . '::LINK_TYPE')) {
            throw new RuntimeException(sprintf('Missing const: LINK_TYPE on %s', static::class));
        }

        return static::LINK_TYPE;
    }
}
