<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;

/**
 * ElementParser
 * @package Infomaker\Everyware\NewsML\Parsers
 */
class ElementParser implements ItemParser
{
    public const TAG = 'element';

    /**
     * Contains a list of inline elements allowed to pass through the filter by default
     *
     * @var array
     */
    public const ALLOWED_TAGS = [
        'span',
        'i',
        'b',
        'em',
        'strong',
        'sup',
        'sub',
        'br',
        'hr',
        'a',
        'script',
        'iframe',
        'mark'
    ];

    public const FORBIDDEN_TAGS = [];

    /**
     * Contains a list of inline elements allowed to pass through the filter
     *
     * @var array
     */
    protected $allowedTags;
    protected $forbiddenTags;

    public function __construct()
    {
        $this->setAllowedTags(self::ALLOWED_TAGS);
        $this->setForbiddenTags(self::FORBIDDEN_TAGS);
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new Item($element);
        $item->fill([
            'type' => $item->getType(),
            'content' => $item->getFilteredContent($this->allowedTags, $this->forbiddenTags)
        ]);

        return [$item];
    }

    public function addAllowedTags(array $tags): void
    {
        $this->allowedTags = array_replace((array)$this->allowedTags, $tags);
    }

    public function addForbiddenTags(array $tags): void
    {
        $this->forbiddenTags = array_replace((array)$this->forbiddenTags, $tags);
    }

    public function setAllowedTags(array $tags): void
    {
        $this->allowedTags = $tags;
    }

    public function setForbiddenTags(array $tags): void
    {
        $this->forbiddenTags = $tags;
    }
}
