<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;

/**
 * IdfParser
 * @package Infomaker\Everyware\NewsML\Parsers
 */
class IdfParser implements ItemParser
{

    /**
     * @var array
     */
    protected $parsers;

    public function __construct(ElementParser $elementParser, ObjectParser $objectParser, GroupParser $groupParser)
    {
        $this->parsers = [
            ElementParser::TAG => $elementParser,
            ObjectParser::TAG => $objectParser,
            GroupParser::TAG => $groupParser
        ];
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $items = [];

        foreach ($element as $tag => $item) {
            $parser = $this->parsers[$tag] ?? null;
            if ($parser instanceof ItemParser) {
                $items[] = $parser->parse($item);
            }
        }

        return array_merge(...$items);
    }
}
