<?php

namespace Spec\Infomaker\Everyware\NewsML\Objects;

use Infomaker\Everyware\NewsML\Interfaces\ItemWithImage;
use Infomaker\Everyware\NewsML\Interfaces\ItemWithLinks;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Objects\ImageItem;
use Infomaker\Everyware\NewsML\Objects\ContentPartItem;
use PhpSpec\ObjectBehavior;
use SimpleXMLIterator;
use Tightenco\Collect\Contracts\Support\Arrayable;

class ContentPartItemSpec extends ObjectBehavior
{
    private $defaultAttributes = [
        'id' => 'MTUwLDE4Miw1NCwxMjc',
        'type' => 'x-im/content-part',
        'title' => 'Lorem ipsum dolor sit',
        'uuid' => '778d7968-35e3-4347-b085-c4724ae8c885'
    ];

    public function let(): void
    {
        static $xml;

        if ( ! $xml instanceof SimpleXMLIterator) {
            $xml = new SimpleXMLIterator('<object/>');

            foreach ($this->defaultAttributes as $name => $value) {
                $xml->addAttribute($name, $value);
            }
        }

        $this->beConstructedWith($xml);
    }

    public function it_is_initializable(): void
    {
        $this->shouldHaveType(Item::class);
        $this->shouldHaveType(ContentPartItem::class);
    }

    public function it_should_implement_correct_interfaces()
    {
        $this->shouldImplement(Arrayable::class);
        $this->shouldImplement(ItemWithImage::class);
        $this->shouldImplement(ItemWithLinks::class);
    }

    public function it_should_return_list_of_links(Item $item)
    {
        $linkList = [$item];

        $this->set('links', $linkList);
        $this->getLinks()->shouldReturn($linkList);
    }

    public function it_should_return_empty_list_of_links_if_not_set()
    {
        $this->getLinks()->shouldReturn([]);
    }

    public function it_can_determine_if_the_object_includes_links(Item $item)
    {
        $this->hasLinks()->shouldBe(false);

        $this->set('links', []);
        $this->hasLinks()->shouldBe(false);

        $this->set('links', [$item]);
        $this->hasLinks()->shouldBe(true);
    }

    public function it_should_extract_image_from_links(ImageItem $image)
    {
        $this->getImage()->shouldReturn(null);

        $this->set('links', [$image]);
        $this->getImage()->shouldReturn($image);
    }

    public function it_can_determine_if_the_object_includes_an_image(Item $item, ImageItem $image)
    {
        $this->hasImage()->shouldBe(false);

        $this->set('links', [$item, 'Not ' . ImageItem::class]);
        $this->hasImage()->shouldBe(false);

        $this->set('links', [$image]);
        $this->hasImage()->shouldBe(true);
    }
}
