<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\GroupParser;
use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;
use Spec\Infomaker\Everyware\NewsML\CollectionParserSpec;

class GroupParserSpec extends CollectionParserSpec
{
    function let()
    {
        $this->beConstructedWith(
            new ElementParser(),
            new ObjectParser(['x-im/imagegallery' => new ImageGalleryParser()])
        );
    }

    function it_is_initializable()
    {
        $this->shouldHaveType(GroupParser::class);
    }

    public function it_can_parse_elements_and_objects()
    {
        $xml = <<<XML
<group>
    <element id="paragraph-273ee570c1469bdf5badeea5f0524166" type="headline"><strong>Strong Headline</strong></element>
    <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
        <links>
            <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                <data>
                    <height>1109</height>
                </data>
            </link>
        </links>
    </object>
</group>
XML;

        $this->validateXML($xml, [
            [
                'type' => 'headline',
                'content' => '<strong>Strong Headline</strong>'
            ],
            [
                'type' => 'x-im/imagegallery'
            ]
        ]);
    }

    public function it_will_return_an_empty_object_if_ObjectParser_initalizes_without_parsers()
    {
        $xml = <<<XML
<group>
    <object type="x-im/imagegallery" id="imagegallery-1d202026f6d7a8511eeaf522a366d74e">
        <links>
            <link rel="image" type="x-im/image"  uri="im://image/NygPCiTpwG3j0WItNRSc3a6AbY0.jpg" uuid="c965e053-6176-58ec-81ad-d2d4c778761c">
                <data>
                    <height>1109</height>
                </data>
            </link>
        </links>
    </object>
    <object id="youtubeembed-b2f175bffda606e12deeb40f7aa6e962" type="x-im/youtube" url="https://www.youtube.com/watch?v=dQw4w9WgXcQ&amp;feature=youtu.be&amp;t=42" uri="https://www.youtube.com/watch?v=dQw4w9WgXcQ&amp;feature=youtu.be&amp;t=42">
        <data>
            <start>57.2</start>
        </data>
        <links>
            <link rel="alternate" type="text/html" url="https://www.youtube.com/watch?v=dQw4w9WgXcQ&amp;feature=youtu.be&amp;t=42" title="Click link to view content">
                <data>
                    <context>Video</context>
                    <provider>YouTube</provider>
                </data>
            </link>
            <link rel="alternate" type="image/jpg" url="https://i.ytimg.com/vi/dQw4w9WgXcQ/hqdefault.jpg">
                <data>
                    <width>480</width>
                    <height>360</height>
                </data>
            </link>
        </links>
    </object>
</group>
XML;

        $this->beConstructedWith(new ElementParser(), new ObjectParser([]));

        $this->validateXML($xml, []);
    }
}
