<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\HtmlEmbedParser;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class HtmlEmbedParserSpec extends ParserSpec
{

    function it_is_initializable()
    {
        $this->shouldHaveType(HtmlEmbedParser::class);
    }

    public function it_should_parse_an_object()
    {
        $content = <<<HTML
<div>
    <h1>Hello World</h1>;
    <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit. Aspernatur atque beatae consectetur dolore dolorem enim esse eum fugiat laudantium molestias nisi odio, pariatur quaerat quam qui quis suscipit vel vitae!</p>
</div>
HTML;

        $xml = <<<XML
<object id="htmlembed-302418e2ed9fae687b72ed0ffeb7f604" type="x-im/htmlembed">
    <data>
        <text>
            <![CDATA[$content]]>
        </text>
        <format>html</format>
    </data>
</object>
XML;

        $this->validateXML($xml, [
            'type' => 'x-im/htmlembed',
            'format' => 'html',
            'content' => $content
        ]);
    }

    public function it_should_support_none_html()
    {
        $content = 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Aspernatur atque beatae consectetur dolore dolorem enim esse eum fugiat laudantium molestias nisi odio, pariatur quaerat quam qui quis suscipit vel vitae!';
        $xml = <<<XML
<object id="htmlembed-302418e2ed9fae687b72ed0ffeb7f604" type="x-im/htmlembed">
    <data>
        <text>$content</text>
        <format>html</format>
    </data>
</object>
XML;

        $this->validateXML($xml, [
            'type' => 'x-im/htmlembed',
            'format' => 'html',
            'content' => $content
        ]);
    }

    public function it_should_return_default_values_if_not_set()
    {

        $xml = <<<XML
<object id="htmlembed-302418e2ed9fae687b72ed0ffeb7f604" type="x-im/htmlembed">
    <data>
        <text/>
        <format>html</format>
    </data>
</object>
XML;

        $this->validateXML($xml, [
            'content' => ''
        ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/htmlembed');
    }
}
