<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\IframelyParser;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class IframelyParserSpec extends ParserSpec
{
    function it_is_initializable()
    {
        $this->shouldHaveType(IframelyParser::class);
    }

    public function it_should_parse_an_object()
    {
        $xml = <<<XML
 <object id="iframely-e98933e6ea201687a18ee90e6a362188" type="x-im/iframely" url="iframely-url">
    <data>
        <title>Title</title>
        <embedCode>
            <![CDATA[<iframe src="..."></iframe>]]>
        </embedCode>
    </data>
    <links>
        <link rel="alternate" type="text/html" title="Title" url="iframely-url">
            <data>
                <context>Social</context>
                <description>Description</description>
                <provider>Provider</provider>
            </data>
        </link>
        <link rel="alternate" type="image/jpg" url="iframely-image">
            <data>
                <width>1024</width>
                <height>768</height>
            </data>
        </link>
    </links>
</object>
XML;
        $this->validateXML($xml, [
            'id' => 'iframely-e98933e6ea201687a18ee90e6a362188',
            'type' => 'x-im/iframely',
            'url' => 'iframely-url',
            'content' => '<iframe src="..."></iframe>',
            'links' => [
                [
                    'url' => 'iframely-url',
                    'type' => 'text/html',
                    'data' => [
                        'context' => 'Social',
                        'description' => 'Description',
                        'provider' => 'Provider'
                    ]
                ],
                [
                    'url' => 'iframely-image',
                    'type' => 'image/jpg',
                    'data' => [
                        'width' => '1024',
                        'height' => '768'
                    ]
                ]
            ]
        ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/iframely');
    }
}
