<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers\Metadata;

use Infomaker\Everyware\NewsML\Parsers\Metadata\PersonParser;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class PersonParserSpec extends ParserSpec
{
    function it_is_initializable()
    {
        $this->shouldHaveType(PersonParser::class);
    }

    public function it_can_parse_an_object()
    {
        $xml = <<<XML
<object id="1pGrYW69CaIf" type="x-im/person">
    <data>
        <email>john.doe@navigaglobal.com</email>
        <phone>+123456789</phone>
        <streetAddress>Street Address 99</streetAddress>
        <city>City</city>
        <country>Country</country>
        <postalCode>123456</postalCode>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'type' => 'x-im/person',
            'id' => '1pGrYW69CaIf',
            'email' => 'john.doe@navigaglobal.com',
            'phone' => '+123456789',
            'streetAddress' => 'Street Address 99',
            'city' => 'City',
            'country' => 'Country',
            'postalCode' => '123456'
        ]);
    }

    public function it_will_add_all_data_child_nodes()
    {
        $xml = <<<XML
<object id="1pGrYW69CaIf" type="x-im/person">
    <data>
        <something>Something</something>
        <unknownTag>UnknownTag</unknownTag>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'something' => 'Something',
            'unknownTag' => 'UnknownTag',
        ]);
    }

    public function it_can_return_type_to_be_parsed()
    {
        $this->typeToParse()
            ->shouldReturn('x-im/person');
    }
}
