<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\TeaserParser;
use Infomaker\Everyware\Support\Format;
use Spec\Infomaker\Everyware\NewsML\ParserSpec;

class TeaserParserSpec extends ParserSpec
{

    function it_is_initializable()
    {
        $this->shouldHaveType(TeaserParser::class);
    }

    public function it_should_parse_an_object()
    {
        $xml = <<<XML
<object id="MjE5LDE2MywyNDgsMjA4" type="x-im/teaser" title="Lorem ipsum dolor sit">
        <data>
            <title>Lorem ipsum dolor sit</title>
            <text>Mauris at libero condimentum sapien malesuada efficitur non id nibh.</text>
            <subject>Lorem ipsum dolor sit amet, consectetur adipiscing elit</subject>
            <customText>Duis aute irure dolor</customText>
        </data>
        <links>
            <link rel="image" type="x-im/image" uri="im://image/fmglga0fK54ZwKjnufQgG027eOA.png" uuid="7d6450cd-27a6-589d-a84a-d6bb635cb542">
                <data>
                    <width>1080</width>
                    <height>1080</height>
                    <imageInstructions>This image has rights on how to use it...</imageInstructions>
                </data>
                <links>
                    <link title="16:9" rel="crop" type="x-im/crop" uri="im://crop/0/0.21875/1/0.5625"/>
                    <link title="1:1" rel="crop" type="x-im/crop" uri="im://crop/0/0/1/1"/>
                    <link rel="focal-point" type="x-im/focal-point">
                        <data>
                            <x>123</x>
                            <y>456</y>
                        </data>
                    </link>
                </links>
            </link>
            <link rel="article" type="x-im/article" title="Tintin i Hajsjön" uuid="22885008-ec24-4b59-8edf-67109322f49c"/>
        </links>
    </object>
XML;

        $this->validateXML($xml, [
            'id' => 'MjE5LDE2MywyNDgsMjA4',
            'type' => 'x-im/teaser',
            'title' => 'Lorem ipsum dolor sit',
            'headline' => 'Lorem ipsum dolor sit',
            'text' => 'Mauris at libero condimentum sapien malesuada efficitur non id nibh.',
            'subject' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit',
            'alttitle' => 'Duis aute irure dolor',
            'links' => [
                [
                    'type' => 'x-im/image',
                    'uuid' => '7d6450cd-27a6-589d-a84a-d6bb635cb542',
                    'width' => '1080',
                    'height' => '1080',
                    'instructions' => 'This image has rights on how to use it...',
                    'crop' => [
                        '16:9' => [
                            'x' => Format::formatNumberToImengineFloat(0),
                            'y' => Format::formatNumberToImengineFloat(0.21875),
                            'width' => Format::formatNumberToImengineFloat(1),
                            'height' => Format::formatNumberToImengineFloat(0.5625),
                        ],
                        '1:1' => [
                            'x' => Format::formatNumberToImengineFloat(0),
                            'y' => Format::formatNumberToImengineFloat(0),
                            'width' => Format::formatNumberToImengineFloat(1),
                            'height' => Format::formatNumberToImengineFloat(1),
                        ],
                    ],
                    'focal-point' => [
                        ['x' => '123', 'y' => '456']
                    ]
                ],
                [
                    'type' => 'x-im/article',
                    'title' => 'Tintin i Hajsjön',
                    'uuid' => '22885008-ec24-4b59-8edf-67109322f49c'
                ]
            ]
        ]);
    }

    public function it_should_support_text_styles()
    {
        $xml = <<<XML
<object id="MjE5LDE2MywyNDgsMjA4" type="x-im/teaser" title="Lorem ipsum dolor sit">
    <data>
        <title>Lorem ipsum dolor sit</title>
        <text>
            <strong>Text</strong> <em>text</em> with <mark>markup</mark>
        </text>
        <subject>
            <em>Subject</em> <strong>text</strong> with <mark>markup</mark>
        </subject>
    </data>
</object>
XML;

        $this->validateXML($xml, [
            'text' => '<strong>Text</strong> <em>text</em> with <mark>markup</mark>',
            'subject' => '<em>Subject</em> <strong>text</strong> with <mark>markup</mark>'
        ]);
    }

    public function it_should_only_have_allowed_tags()
    {
        $xml = <<<XML
<object id="MjE5LDE2MywyNDgsMjA4" type="x-im/teaser" title="Headline text without markup">
    <data>
        <title>Headline text without markup</title>
        <text>
            <td><strong>Text</strong></td> <em>text</em> with <mark>markup</mark> <a href="www.google.com">link text</a>
        </text>
        <subject>
            <div><em>Subject</em> <strong>text</strong> with <mark>markup</mark></div> <a href="www.google.com">link text</a>
        </subject>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'text' => '<strong>Text</strong> <em>text</em> with <mark>markup</mark> link text',
            'subject' => '<em>Subject</em> <strong>text</strong> with <mark>markup</mark> link text'
        ]);
    }

    public function it_should_support_idf_text()
    {
        $xml = <<<XML
<object id="MjE5LDE2MywyNDgsMjA4" type="x-im/teaser" title="Headline text without markup">
    <data>
        <title>Headline text without markup</title>
        <text format="idf">
            <element id="paragraph-88beb76cb6af9ca39303bebc20497c56" type="body">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</element>
            <element id="paragraph-360f09442467b39801c6f60971b9c02c" type="body">Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</element>
            <element id="paragraph-337d42c0a735a1faab645382bbf39fff" type="body"><td><strong>Text</strong></td> <em>text</em> with <mark>markup</mark> <a href="www.google.com">link text</a></element>    
        </text>
        <subject>
            <div><em>Subject</em> <strong>text</strong> with <mark>markup</mark></div> <a href="www.google.com">link text</a>
        </subject>
    </data>
</object>
XML;
        $this->validateXML($xml, [
            'text' => implode(' ', [
                'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
                'Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.',
                '<strong>Text</strong> <em>text</em> with <mark>markup</mark> link text'
            ]),
            'subject' => '<em>Subject</em> <strong>text</strong> with <mark>markup</mark> link text'
        ]);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/teaser');
    }
}
